%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% computeEstimatedFirstStageISE.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 24, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ISE, ISErescaled] = ...
    computeEstimatedFirstStageISE(...
    linCombPdfHat,linCombPdfHatRescaled,...
    linCombPdfTrue,GridParams,useWeightedISE)
%% 1. Set parameters and initialize vectors

nTgrid = GridParams.nTgrid;
nSgrid = GridParams.nSgrid;

ISE = nan(nTgrid,1);
ISErescaled = nan(nTgrid,1);

%% 2. For each (t1,t2) point, compute the ISE of that linComb estimate
for it = 1:nTgrid
    
    if useWeightedISE == 0
    
    ISE(it) = ...
      sum((linCombPdfHat(it,:) - linCombPdfTrue(:,it)').^2)/nSgrid;
  
    ISErescaled(it) = ...
      sum((linCombPdfHatRescaled(it,:) - linCombPdfTrue(:,it)').^2)/nSgrid;
  
    elseif useWeightedISE == 1
        
    ISE(it) = ...
      sum(((linCombPdfHat(it,:) - ...
        linCombPdfTrue(:,it)').^2).*linCombPdfTrue(:,it)')/nSgrid;

    ISErescaled(it) = ...
      sum(((linCombPdfHatRescaled(it,:) - ...
        linCombPdfTrue(:,it)').^2).*linCombPdfTrue(:,it)')/nSgrid;
    
    end
  
end

end