%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% computeFstatistic.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 14, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function Fstat = computeFstatistic(Y2,Z)
% Y2 = Y(:,2)

    n = size(Y2,1);

    Xmat = [ones(n,1) Z(:,1) Z(:,2)]; %n-by-3

    piHat = (Xmat'* Xmat)\(Xmat'* Y2);

    inverseDesignMatrix = (Xmat'* Xmat)\eye(3);

    residuals = Y2 - Xmat*piHat;

    sigmaSquardHat = (residuals' * residuals)/n;

    % This assumes homoskedasticity
    varianceMatrix = sigmaSquardHat * inverseDesignMatrix;

    % In this simple case the F-stat equals the squared T-stat
    Tstat = piHat(3)/sqrt(varianceMatrix(3,3));

    Fstat = Tstat^2;

end
