%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% computeOptimalBandwidthsFromCluster.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 25, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
% NOTES: Either
% 1. Download all MISE datasets locally and then run this, or
% 2. Run this directly on the server
%
% Either way, run this after the first step---computing the MISEs for each
% dgp and each bandwidth option---is complete.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function computeOptimalBandwidthsFromCluster()

[dgpGrid, ~, ~] = setnSimsAndDgpGrid();

for i = 1:length(dgpGrid)
    
    selectedDgp = i;
    
    dgpChoice = dgpGrid(selectedDgp,1);
    normalZ = dgpGrid(selectedDgp,2);
    sampleSize = dgpGrid(selectedDgp,3);

    [~,EstimationParams,GridParams,~,~] = ...
        setAdditionalParameters(dgpChoice,normalZ);

    EstimationParams = setRadonBandwidths(dgpChoice,EstimationParams);

    % Aggregate all the MISE results together and compute the optimal
    % bandwidths
    computeOptimalBandwidthsWrapper(...
        sampleSize,dgpChoice,normalZ,EstimationParams,GridParams);

end

end