%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% computeOptimalBandwidthsWrapper.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: March 21, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function computeOptimalBandwidthsWrapper(...
    sampleSize,dgpChoice,normalZ,EstimationParams,GridParams)

nRadonBdw = length(EstimationParams.radonBandwidths);

% For aggregating the MISE's
MISE = nan(GridParams.nTgrid,nRadonBdw);
MISErescaled = nan(GridParams.nTgrid,nRadonBdw);

% Aggregate MISE's by loading across all saved files
for i = 1:nRadonBdw
   
    load(sprintf('../output_bandwidths/MISEs_n%d_dgp%d_nZ%d_h%d.mat',...
        sampleSize,dgpChoice,normalZ,i),...
       'thisMISE','thisMISErescaled');

    % Store this MISE in the overall vector (nTgrid-by-nRadonBdw)
    MISE(:,i) = thisMISE;
    MISErescaled(:,i) = thisMISErescaled;
    clear thisMISE thisMISErescaled;
   
end

%% 3. Compute optimal bandwidth

    % The output here is a GridParams.nTgrid-by-1 column vector of
    % optimal bandwidths. That is, for each (t1,t2) pair, we find a
    % different optimal bandwidth.
    [optimalBandwidth, optimalBandwidthRescaled] = ...
        computeOptimalBandwidths(MISE,MISErescaled,EstimationParams);

    MISE_optimalBandwidth = optimalBandwidth;
    MISE_optimalBandwidth_resc = optimalBandwidthRescaled;

    hstar_MISE = num2cell(MISE_optimalBandwidth);
    hstar_MISE_resc = num2cell(MISE_optimalBandwidth_resc);
    
    EstimationParams.bandwidthGrid = hstar_MISE;
    EstimationParams.bandwidthGrid_resc = hstar_MISE_resc;
    
    save(sprintf('../datasets_bandwidths/hstar_n%d_dgp%d_nZ%d.mat',...
        sampleSize,dgpChoice,normalZ),...
       'GridParams','dgpChoice','EstimationParams','normalZ');

end