%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% computeQuantile.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 11, 2015
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function tauQuantile = computeQuantile(nQuantileGrid,Zgrid,fgamma2Hat,tau,gammaLB,gammaUB)

% nQuantileGrid = 1000;
quantileGrid = linspace(gammaLB,gammaUB,nQuantileGrid)';
quantileGridStep = (gammaUB-gammaLB)/(nQuantileGrid-1);

% Here I interpolate because Zgrid is somewhat coarse, whereas I want to
% get a much more precise estiamte of the quantile. One option would be to
% re-run everything with a finer Zgrid, but that would take lots of time.
% Instead, I just use linear interpolation (which is what the plots use as
% well)
fgamma2HatInterpolated = interp1(Zgrid,fgamma2Hat,quantileGrid);
% Usage:
% interpolatedvalues = interp1(xSamplePts,funcationValsAtSamplePts,vecOfNewPoints)

cdfgamma2Hat = nan(nQuantileGrid,1);
currentCdf = 0;
for i=1:nQuantileGrid
    currentCdf = currentCdf + fgamma2HatInterpolated(i);
    cdfgamma2Hat(i) = currentCdf*quantileGridStep;
end

% Find the quantile
distance = abs(cdfgamma2Hat - tau);
[val,index] = min(distance);

tauQuantile = quantileGrid(index,:);

end