%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% generateMCdatasets.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: Feb 25, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
% DESCRIPTION: This code generates different data sets for the two-equation
% linear simultaneous equations model with random coefficients. The code
% saves each dataset as a separate .mat file so they can be analyzed in
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function generateMCdatasets(sampleSize,DgpParams,dgpChoice,...
    nSimulations,datasetFolder,normalZ)
%% Load parameters

[dist_gamma,alpha_gamma,beta_gamma,mu_gamma,sigma_gamma,shift,...
    scale, mu_u,sigma_u,mu_z,sigma_z,theta,betaReg] = ...
    setgenerateMCdatasetsParameters(DgpParams,normalZ);

%% Generate sample datasets
% Data:
%
% Ydata: (n by 2) vector of outcomes (Y1,Y2)
%
% Z: (n by 2) vector of instruments (Z1,Z2). 
% First column is the covariate for person 1, which is excluded from 
% person 2's equation. Second column is the covariate for person 2, which
% is excluded from person 1's equation.

for i = 1:nSimulations

    [Y,Z,Z1_coeffs,Z2_coeffs,Intercepts] = ...
        generateSystemsData(sampleSize,theta,betaReg,...
        alpha_gamma,beta_gamma,mu_gamma,sigma_gamma,dist_gamma,...
        mu_u,sigma_u,mu_z,sigma_z,normalZ);

    % Save dataset
    cd(strcat('../',datasetFolder));

    saveFileName = ...
        sprintf('MCdataset_n%d_dgp%d_nZ%d_sim%d.mat',...
            sampleSize,dgpChoice,normalZ,i);

    save(saveFileName,'Y','Z','Z1_coeffs','Z2_coeffs','Intercepts');

    cd ../code

end

end