%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% generateRandomCoefficientsData.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 14, 2015
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
% DESCRIPTION: Generate endogenous variable random coefficients
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [Z1_coeffs,Z2_coeffs,Intercepts] = ...
    generateRandomCoefficientsData(nSims,theta,betaReg,...
    alpha_gamma,beta_gamma,mu_gamma,sigma_gamma,dist_gamma,gammaLB,gammaUB)
%%

% Independent truncated normal(mu_gamma,sigma_gamm) 

% Note that mu_gamma is not exactly equal to the true mean
if dist_gamma == 1
    gammaVec(:,1) = generateUnivariateData(nSims,2,[],[],mu_gamma,sigma_gamma);
    gammaVec(:,2) = generateUnivariateData(nSims,2,[],[],mu_gamma,sigma_gamma);

% Independent Beta(alpha_gamma,rho_gamma)
elseif dist_gamma == 2
    gammaVec(:,1) = generateUnivariateData(nSims,3,alpha_gamma,beta_gamma,[],[]);
    gammaVec(:,2) = generateUnivariateData(nSims,3,alpha_gamma,beta_gamma,[],[]);

end

% Usual case is gammaLB = 0 and gammaUB = theta.

gamma1 = gammaLB + (gammaUB - gammaLB)*gammaVec(:,1);
gamma2 = gammaLB + (gammaUB - gammaLB)*gammaVec(:,2);

Z1_coeffs(:,1) = betaReg./(1-gamma1.*gamma2);
Z1_coeffs(:,2) = betaReg*gamma2./(1-gamma1.*gamma2);

Z2_coeffs(:,1) = betaReg*gamma1./(1-gamma1.*gamma2);
Z2_coeffs(:,2) = betaReg./(1-gamma1.*gamma2);

mu_u = 0;
sigma_u = 1;

% Assume U1 and U2 are independent Normal(mu_u,sigma_u^2)
U1 = generateUnivariateData(nSims,1,[],[],mu_u,sigma_u);
U2 = generateUnivariateData(nSims,1,[],[],mu_u,sigma_u);

Intercepts(:,1) = (U1 + U2.*gamma1)./(1-gamma1.*gamma2);
Intercepts(:,2) = (U2 + U1.*gamma2)./(1-gamma1.*gamma2);

end