%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plotFinalPdfEstimateEmpirical.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 14, 2015
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function plotFinalPdfEstimateEmpirical(DgpParams,...
    fgamma2Hat,Zgrid,printDirectory,fgammaHat_upperBand,fgammaHat_lowerBand)

gammaLowerBound = DgpParams.gammaLowerBound;
gammaUpperBound = DgpParams.gammaUpperBound;

% Sets number of tick marks = 5 if gammaUpperBound > 0.75. 
% Minimum distance between tick marks is 0.25.
%
% Recall that theta is the upper bound on the support of gamma2.
ticks = (gammaLowerBound:(ceil(gammaUpperBound)/4):gammaUpperBound);
if ticks(end) ~= gammaUpperBound
    ticks = [ticks gammaUpperBound];
end

if gammaLowerBound == -0.95
    ticks = [-0.95 -0.75 -0.5 -0.25 0 0.25 0.5 0.75 0.95];
end

h = figure;

hold on
plot(Zgrid,fgamma2Hat,'k-','LineWidth',1.5);

if nargin == 6
    plot(Zgrid,fgammaHat_upperBand,'k:','LineWidth',2.5);
    plot(Zgrid,fgammaHat_lowerBand,'k:','LineWidth',2.5);   
end

box off
set(gca,'ycolor',[0.8 0.8 0.8]) % Remove y-axis %[0.8 0.8 0.8] = get(h,'color')
set(gca,'ytick',[]); % Remove y-axis
set(gca,'FontSize',16)
set(gca,'XLim',[gammaLowerBound gammaUpperBound]);  % Sets range of the x-axis
set(gca,'XTick',ticks); % Set tick marks
hold off

if nargin >= 4
    print(h,'-deps',printDirectory);
end

end