%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plotFinalPdfEstimateVsTruth.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: March 5, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function plotFinalPdfEstimateVsTruth(GridParams,DgpParams,...
    fgamma2True,fgamma2Hat,Zgrid,dgpChoice,printDirectory,...
    fgamma2HatMatrix_lowerBand,fgamma2HatMatrix_upperBand)

% Load parameters
nSgrid = GridParams.nSgrid;
nZgrid = GridParams.nZgrid;
nTgrid = GridParams.nTgrid;
nVgrid = GridParams.nVgrid;
TgridLowerBound = GridParams.TgridLowerBound;
TgridUpperBound = GridParams.TgridUpperBound;
VgridLowerBound = GridParams.VgridLowerBound;
VgridUpperBound = GridParams.VgridUpperBound;
gammaLowerBound = DgpParams.gammaLowerBound;
gammaUpperBound = DgpParams.gammaUpperBound;

% Sets number of tick marks = 5 if gammaUpperBound > 0.75. 
% Minimum distance between tick marks is 0.25.
%
% Recall that theta is the upper bound on the support of gamma2.
ticks = (gammaLowerBound:(ceil(gammaUpperBound)/4):gammaUpperBound);
if ticks(end) ~= gammaUpperBound
    ticks = [ticks gammaUpperBound];
end

h = figure;

if nargin >= 7
    h = figure('visible','off');
end

hold on
plot(Zgrid,fgamma2True,'k--','LineWidth',1.5);
plot(Zgrid,fgamma2Hat,'k-','LineWidth',1.5);

if nargin == 9
    plot(Zgrid,fgamma2HatMatrix_upperBand,'k:','LineWidth',2.5);
    plot(Zgrid,fgamma2HatMatrix_lowerBand,'k:','LineWidth',2.5);    
end

box off
set(gca,'ycolor',[0.8 0.8 0.8]) % Remove y-axis %[0.8 0.8 0.8] = get(h,'color')
set(gca,'ytick',[]); % Remove y-axis
set(gca,'FontSize',16)
set(gca,'XLim',[gammaLowerBound gammaUpperBound]);  % Sets range of the x-axis
set(gca,'XTick',ticks); % Set tick marks
hold off

if nargin >= 7
    print(h,'-deps',printDirectory);
end

end