%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plotLinearCombPdf.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 18, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
% DESCRIPTION: Code to produce the four plots in figure 4 of the 
% supplemental online appendix.
%
% You must manually set the first two parameters to produce these four
% plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

selectedDgp = 13; % 1 or 13 (This does NOT refer to dgpChoice; rather it
                  % refers to an element of dgpGrid
                  
it = 2; % 1 or 2

[dgpGrid, nSimulations, nSimulations_MISE] = setnSimsAndDgpGrid();

dgpChoice = dgpGrid(selectedDgp,1);
normalZ = dgpGrid(selectedDgp,2);
sampleSize = dgpGrid(selectedDgp,3);

useWeightedISE = 1;

[DgpParams,EstimationParams,GridParams,GridOutputs,linCombPdfTrue] = ...
    setAdditionalParameters(dgpChoice,normalZ);

%% Plot pdf

[~,~,~,~,linCombPdfTrue] = ...
    setAdditionalParameters(dgpChoice,normalZ);  

h = figure;
hold on
plot(GridOutputs.Sgrid(:,it),linCombPdfTrue(:,it)','k-','LineWidth',1.5);
box off
set(gca,'ycolor',[0.8 0.8 0.8]) % Remove y-axis %[0.8 0.8 0.8] = get(h,'color')
set(gca,'ytick',[]); % Remove y-axis
set(gca,'FontSize',16)
hold off

printDirectory = sprintf('../images/linCombPdf_dgp%d_it%d.eps',...
        selectedDgp,it);

print(h,'-deps',printDirectory);
