%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% runComputeMISE_cluster.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 20, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function runComputeMISE_cluster(dgpGridChoice)
%% FOR CLUSTER IN PARALLELS
% Get the current job_id from the server.
    job_id_string = getenv('SLURM_ARRAY_TASK_ID');
    job_id = str2double(job_id_string);
% job_id in this code will index the particular radonBandwidth we choose

% To run this code locally, just comment out the above two lines 
% and use this instead:
%
%job_id_string = '1';
%job_id = str2double(job_id_string);
%
% where '1' is changed to any number indexing the choice of radonBandwidth
 
%% 1. Define the possible dgps we will consider

[dgpGrid, ~, nSimulations_MISE] = setnSimsAndDgpGrid();
    
%% 2. Select dgp

    dgpChoice = dgpGrid(dgpGridChoice,1);
    normalZ = dgpGrid(dgpGridChoice,2);
    sampleSize = dgpGrid(dgpGridChoice,3);
    
    diary(sprintf('../output/computeMISE_n%d_dgp%d_nZ%d_bdw%d.txt',...
         sampleSize,dgpChoice,normalZ,job_id));

%% 3. Continue setting parameters
% This step defines GridParams, EstimationParams, 
% GridOutputs, and linCombPdfTrue, and then saves them in a .mat file

[DgpParams,EstimationParams,GridParams,GridOutputs,linCombPdfTrue] = ...
    setAdditionalParameters(dgpChoice,normalZ);

useWeightedISE = 1;

%% 4. Compute optimal bandwidths

    % This sets the entire vector of bandwidths we want to consider
    EstimationParams = setRadonBandwidths(dgpChoice,EstimationParams);
    
    % Here we select the bandwidth according to the particular job_id
    % obtained from the server
    i = job_id;

    radonBandwidth = EstimationParams.radonBandwidths(i);

    % Compute and save the MISE for this particular choice of bandwidth
    computeMISE(...
       sampleSize,dgpChoice,nSimulations_MISE,normalZ,...
       GridParams,EstimationParams,GridOutputs,linCombPdfTrue,...
       radonBandwidth,i,useWeightedISE);

diary('off');

end