%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% runEmpiricallyCalibratedDgpStats.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 14, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function runEmpiricallyCalibratedDgpStats()

rng(5241,'twister');

n = 500; % Sample size
nSims = 10000;

FstatVec = nan(nSims,1);
massNearSupport = nan(nSims,1);

for i = 1:nSims

%% Set dgp parameters
mu_u = -2;
sigma_u = 0.8;
beta = 1;

mu_z = 2.8;
sigma_z = 0.8;

%% generate gamma's   

alpha = 0.3;
sigma = [.05,.06];
mu = [.3,.7];

% gamma's = normal mixture
gamma1 = generateUnivariateData(n,5,alpha,[],mu,sigma);
gamma2 = generateUnivariateData(n,5,alpha,[],mu,sigma);

%% Z's = normal
Z1 = mu_z + sigma_z*randn(n,1);
Z2 = mu_z + sigma_z*randn(n,1);

%% generate additive unobservables as N(mu_u,sigma_u^2)
U1 = mu_u + sigma_u*randn(n,1);
U2 = mu_u + sigma_u*randn(n,1);

%% generate Y2 data from reduced-form equation

denom = 1-gamma1.*gamma2;
Var1 = (gamma2.*Z1)./denom;
Var2 = Z2./denom;
Var3 = U2./denom;
Var4 = (gamma2.*U1)./denom;

Y2 = (Var1*beta + Var2*beta + Var3 + Var4);

% hist(Y2,40)

%% Compute Fstat

Fstat = computeFstatistic(Y2,[Z1 Z2]);
FstatVec(i) = Fstat;

%% Compute proportion of mass near the true support [0,4]

massNearSupport(i) = mean((Y2 >= -1).*(Y2 <= 5));

end

%% Display results

mean(massNearSupport)
mean(FstatVec)

end