%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% runGenerateDatasets.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 20, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
% DESCRIPTION: Generates all datasets used in the Monte Carlo simulations
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function runGenerateDatasets()
%% 0. Define the possible dgps we will consider

[dgpGrid, nSimulations, nSimulations_MISE] = setnSimsAndDgpGrid();

%% 1. Generate all datasets.
% There are two kinds of datasets: 
% (1) those used for computing the optimal bandwidth and
% (2) those used for the actual simulations, given the optimal bandwidth
%
% In this section I generate all of these datasets for each of the 14 dgps
% discussed above.

    % Set seed
    rng(5241,'twister');

    for i = 1:length(dgpGrid)
        
        display(i);

        dgpChoice = dgpGrid(i,1);
        normalZ = dgpGrid(i,2);
        sampleSize = dgpGrid(i,3);

        DgpParams = setDgpParams(dgpChoice);

        % (1) For computing optimal bandwidths
        generateMCdatasets(sampleSize,DgpParams,dgpChoice,...
            nSimulations_MISE,'datasets_MISE',normalZ);

        % (2) For actual simulations
        generateMCdatasets(sampleSize,DgpParams,dgpChoice,...
            nSimulations,'datasets',normalZ);

    end

    clear i dgpChoice normalZ sampleSize DgpParams;

end % of function