%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% runTSLSestimation.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 9, 2015
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
% DESCRIPTION: Loads each dataset, computes the TSLS estimate of gamma2, 
% the endogenous variable on the second equation, and then saves the
% estimated coefficients
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function runTSLSestimation(sampleSize,dgpChoice,nSimulations,normalZ)

for i=1:nSimulations
    
    simulationNumber = i;
    
    %% Load data
    
    load(sprintf('../datasets/MCdataset_n%d_dgp%d_nZ%d_sim%d.mat',...
        sampleSize,dgpChoice,normalZ,simulationNumber));
    
    % X = [Z ones(sampleSize,1)]; %sampleSize-by-3
    % Y is loaded here too, sampleSize-by-2

    %% 2SLS of the first equation
    
    % Y here is a sampleSize-by-2 vector of (Y1,Y2) values
    Xdata = []; % We don't have covariates in the simulations
    TSLSestimate = computeGamma2TSLS(Y,Z(:,1),Z(:,2),Xdata);
    % Don't forget that the random coefficient is scaled by theta!

    %% Save estimates

    save(sprintf('../estimatesTSLS/MC_TSLS_n%d_dgp%d_nZ%d_sim%d.mat',...
        sampleSize,dgpChoice,normalZ,simulationNumber), 'TSLSestimate');

    
end

end