%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setAdditionalParameters.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 24, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [DgpParams, EstimationParams, GridParams, ...
    GridOutputs, linCombPdfTrue] =  ...
    setAdditionalParameters(dgpChoice,normalZ)
%% 1. Set parameters and compute grids

    % Define dgp relevant parameters
    DgpParams = setDgpParams(dgpChoice);

    % Define numerical approximation parameters
    GridParams = setGridParameters(dgpChoice,DgpParams);

    EstimationParams.r = 1; % Parameter for inverse Radon transform Kernel
    EstimationParams.lambda = 0.8; % Spherical kernel bandwidth;
    EstimationParams.tau = 0; % Amount of trimming for denominator density

    % Compute spherical data kernel estimator normalization constant
    EstimationParams.clambda = ...
        computeSphericalKernelConstant(EstimationParams.lambda);
    
%% 2. Compute integration grid bounds
    
    GridOutputs = computeTandSgrids(GridParams,DgpParams,normalZ);

    linCombPdfTrue = ...
        computeTrueFirstStage(GridParams,DgpParams,GridOutputs);  

end