%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setGridParametersEmpirical.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: May 14, 2015
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Dimension of first stage regressors
GridParams.covariateDimension = 3;

%% T grid

% Paramters for (t1,t2) grid

GridParams.nTgrid = 1000;
GridParams.TgridLowerBound = -M;
GridParams.TgridUpperBound = M;

%% G2 grid

% Parameters for integration in computing the analytical density in the
% first stage. Not needed if the estimated density is used instead
GridParams.nG2grid = 500;

%% S grid

% For integration in step (2) where we integrate over f_{Pi2(t1,t2)}(s)
% to get the characteristic function of (pi12,pi22)
GridParams.nSgrid = 40;

%% controlVarsGrid

GridParams.nControlVarsGrid = 50;

%% Z grid

% Grid of points z which we will evaluate f_{\gamma_2}(z) at.
% This grid defines what our final output will look like, because the pdf
% f_{\gamma_2}(z) is what we are ultimately interested in.
%
% This is a one dimensional plot over the support of \gamma_2, which is
% bounded. 
%
% We will use a uniform grid. So all we need to set is the number of grid
% points and the upper and lower bound of the support of \gamma_2.

GridParams.nZgrid = 250;   % Number of grid points

%% V grid

% The pdf of gamma_2 is a ratio pdf. Following Curtis (1941) [see Masten
% (2017) for citation] this ratio pdf is written as an integral of the
% joint pdf. Hence we need to choose a grid for numerically computing this
% integral. This is a one dimensional grid.
%
% Here we pick the grid of points v over which we will evaluate
% f_{\pi_{22},\pi_{12}(zv,v)
%
% Because this is a one dimensional integrand, we use a uniform grid.
% So we only need to pick the number of grid points and the lower and upper
% bounds of the grid.

GridParams.nVgrid = 50;
% The grid for V should cover the support of
%
% pi_{12} = beta/(1-gamma1*gamma2)
%
GridParams.VgridLowerBound = DgpParams.pi12lowerBound;
GridParams.VgridUpperBound = DgpParams.pi12upperBound;

% See setGridParameters.m for further discussion of this truncation
GridParams.VgridLowerBound = 5; 
GridParams.VgridUpperBound = 12;
