%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setRadonBandwidths.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 23, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
% INPUT: EstimationParams can be an empty structure, and then it will be
% created. Otherwise, the new element .radonBandwidths will be added
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function EstimationParams = setRadonBandwidths(dgpChoice,EstimationParams)

% Setting the same total number of bandwidths per dgp makes it simpler to
% organize the parallelization
nRadonBdw = 50;

% Bandwidths for Radon estimator
    if dgpChoice == 1
        EstimationParams.radonBandwidths = linspace(0.05,2.2,nRadonBdw);

    elseif dgpChoice == 3
        EstimationParams.radonBandwidths = linspace(0.25,14,nRadonBdw);
    
    elseif dgpChoice == 5 ||  dgpChoice == 7
        
        % I chose 70 here because that's about how many nodes Econ has on
        % the cluster so I can run all of these simultaneously without
        % having to wait for any of them to finish
        nRadonBdw = 70;
        
        EstimationParams.radonBandwidths = linspace(0.05,4.4,nRadonBdw);

    end

end