%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setgenerateMCdatasetsParameters.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 25, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [dist_gamma,alpha_gamma,beta_gamma,mu_gamma,sigma_gamma,...
    shift,scale,mu_u,sigma_u,mu_z,sigma_z,theta,betaReg] = ...
    setgenerateMCdatasetsParameters(DgpParams,normalZ)

    dist_gamma = DgpParams.dist;
    alpha_gamma = DgpParams.alpha;
    beta_gamma = DgpParams.beta;
    mu_gamma = DgpParams.mu;
    sigma_gamma = DgpParams.sigma;
    shift = DgpParams.shift;
    scale = DgpParams.scale;

    %% Set parameters which will be fixed across all simulation datasets

    % Distribution of additive unobservables
    if normalZ == 0
        mu_u = DgpParams.intercept; % This is the intercept term
        sigma_u = 1;

    elseif normalZ == 1
        mu_u = DgpParams.intercept;
        sigma_u = 1;
        
    elseif normalZ == 4
        mu_u = DgpParams.intercept;
        sigma_u = 0.04;        
        
    end

    % Distribution of the instrument
    if normalZ == 0
        mu_z = 0;
        sigma_z = 3;

    elseif normalZ == 1
        mu_z = 0;
        sigma_z = 3;

    elseif normalZ == 4
        mu_z = 2.8;
        sigma_z = 0.8;
                
    end

    % Scale for support of random coefficients
    theta = DgpParams.scale;

    % Common coefficient on the instrument in structural equation
    betaReg = DgpParams.betaZcoeff;

end