%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% setnSimsAndDgpGrid.m
%
% AUTHOR: Margaux Luflade and Matthew A. Masten
%
% DATE CREATED: April 25, 2016
% DATE LAST UPDATED: July 14, 2017
%
% REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
% Simultaneous Equations Models", Review of Economic Studies
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [dgpGrid, nSimulations, nSimulations_MISE] = setnSimsAndDgpGrid()
%% Summary of dgps
% There are three key parameters used to set the dgp throughout:
%
% (1) dgpChoice, which sets the distribution of the random coefficients
% gamma, and takes on the following values:
%
% 1 = Independent truncated normal(0.4,0.5) 
% 3 = Independent Beta(6,3)
% 5 = .3*N(.3,.05^2)+.7*N(.7,.06^2)
% 10 = Empirically calibrated dgp
%
% (2) normalZ, which sets the distribution of the instruments in cases 1-5
% above, and takes on the following values:
% 
% 0 = Standard Cauchy distributed Z
% 1 = Normal(0,3) distributed Z
% 4 = Normal(2.8,0.8) distributed Z (as in empirical application)
%
% (3) sampleSize, which sets the sample size.
%
% In the paper I consider 13 dgps, 
% (dgpChoice,normalZ,sampleSize) =

dgpGrid = [1,1,500; % Truncated normal(0.4,0.5)
           1,0,500;
           1,1,1000;
           1,0,1000;
           3,1,500; % Beta(6,3)
           3,0,500;
           3,1,1000;
           3,0,1000;
           5,1,500; % Bimodal
           5,0,500;
           5,1,1000;
           5,0,1000;
           7,3,500]; % Empirically calibrated dgp

nSimulations_MISE = 100; % Number of datasets for computing the MISE

nSimulations = 1000; % Number of simulations/datasets for main MC results
    
end