// AUTHOR: Matthew A. Masten
//
// DATE CREATED: Nov 30, 2013
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies

// Import CSV data for full sample
cd $data_datasets_filepath
insheet using fullsample.csv, clear

// Rename variables so they match the original dta files
forvalues i = 1/2 {
rename currentgpa_`i' currentGPA_`i'
rename laggedgpa_`i' laggedGPA_`i'
}

// Define the two equations in the system
global p1eq "(currentGPA_1 currentGPA_2 laggedGPA_1)"
global p2eq "(currentGPA_2 currentGPA_1 laggedGPA_2)"

// Define the parameter constraints
constraint define 1 [currentGPA_1]currentGPA_2 = [currentGPA_2]currentGPA_1
constraint define 2 [currentGPA_1]laggedGPA_1 = [currentGPA_2]laggedGPA_2
constraint define 3 [currentGPA_1]_cons = [currentGPA_2]_cons

// Run 3SLS
reg3 $p1eq $p2eq, constr(1 2 3) 3sls

// SUR
reg3 $p1eq $p2eq, constr(1 2 3) sure

//// REDUCED FORM REGRESSIONS

// Define the two equations in the system
global redform1eq "(currentGPA_1 laggedGPA_1 laggedGPA_2)"
global redform2eq "(currentGPA_2 laggedGPA_2 laggedGPA_1)"

// Define the parameter constraints
constraint define 4 [currentGPA_1]laggedGPA_1 = [currentGPA_2]laggedGPA_2
constraint define 5 [currentGPA_1]laggedGPA_2 = [currentGPA_2]laggedGPA_1
constraint define 6 [currentGPA_1]_cons = [currentGPA_2]_cons

reg3 $redform1eq $redform2eq, constr(4 5 6) sure
