// AUTHOR: Matthew A. Masten
//
// DATE CREATED: Sept 26, 2012
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies
//
// DESCRIPTION: Compute summary statistics

// Import CSV data for full sample
cd $data_datasets_filepath
insheet using fullSample.csv, clear

// Define control variables
forvalues i = 1/2 {

local covariates_tokeep_`i' /*
*/ currentgpa_`i' /*
*/ laggedgpa_`i'
}

// 1. Convert the pairs dataset to a persons dataset.
cd $data_cr_data_datasets_filepath

forvalues i = 1/2 {
	tempfile using`i'
	preserve
	keep `covariates_tokeep_`i''
	foreach x of varlist _all {
		local newname : subinstr local x "_`i'" ""
		rename `x' `newname'
	}
	save `using`i''
	restore
}

use `using1', clear
append using `using2'

cd $data_datasets_filepath 
save unpaired_estimation_sample, replace

// 2. Output the table
cd $analysis_output_filepath 

eststo clear
estpost tabstat _all, /*
*/ statistics(n mean sd p50 min max) /*
*/ columns(statistics)

// 3. Save outputted table

*Relabel all variables for the table
label variable currentgpa "Current GPA"
label variable laggedgpa "Lagged GPA"

esttab . using summaryStats.tex, /*
*/ cells("count p50(fmt(%9.2g)) mean(fmt(%9.2f)) sd(fmt(%9.2f)) min(fmt(%9.2g)) max(fmt(%9.2g))") /*
*/ noobs label replace nonumbers /*
*/ title("Summary statistics"\label{summaryStatsTable}) nomtitles /*
*/ order(currentgpa laggedgpa)

// addnotes("Table notes go here.")
