// AUTHOR: Matthew A. Masten
//
// DATE CREATED: May 10, 2015
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies

/* Wave 3 AHAA education transcript data */
cd ${ICPSR_root_filepath}ICPSR_27030/DS0001
describe using 27030-0001-Data-REST.dta, short
*Note that there are 2,820 variables. Too many for Stata/IC.
*So we have to specify what variables we want to import.

use /* 
*/ AID /* Identifier
*/ ELMAT945 /* In the 1994-1995 school year, what HS grade were they in?
*/ EAOGPA1-EAOGPA6 /* GPAs in all years of HS (year 1 - year 6)
*/ /* 
*/ using 27030-0001-Data-REST.dta, clear
compress

/* RECODE MISSING VALUES */
// All of the recodes are "might as well be missing" data; i.e., observations
// for which I'll just have to throw them out

// For ELMAT945
// 9993 = year 1 is AFTER 1994-1995; They were in middle school that year
// 9994 = last year of course taking is BEFORE 1994-1995
replace ELMAT945 = . if (ELMAT945 == 9993)
replace ELMAT945 = . if (ELMAT945 == 9994)

// For EAOGPA's
// 9992 = no course-taking data that year [e.g., because they graduated]
// 9995 = no graded course that year
replace EAOGPA1 = . if (EAOGPA1 == 9992 | EAOGPA1 == 9995)
replace EAOGPA2 = . if (EAOGPA2 == 9992 | EAOGPA2 == 9995)
replace EAOGPA3 = . if (EAOGPA3 == 9992 | EAOGPA3 == 9995)
replace EAOGPA4 = . if (EAOGPA4 == 9992 | EAOGPA4 == 9995)
replace EAOGPA5 = . if (EAOGPA5 == 9992 | EAOGPA5 == 9995)
replace EAOGPA6 = . if (EAOGPA6 == 9992 | EAOGPA6 == 9995)

/* Create current and lagged GPA variables */
// Coding of ELMAT945: It tells us their year of school in 1994-1995.
// Example: ELMAT945 = 3 means they were HS juniors (third years) in 1994-1995
gen currentGPA = .
gen laggedGPA = .

forvalues i=1/6 {

	replace currentGPA = EAOGPA`i' if ELMAT945 == `i'

}

forvalues i=2/6 {

	local j = `i' - 1
	replace laggedGPA = EAOGPA`j' if ELMAT945 == `i'

}

// How many people are in 10-12 grade during wave 1 school year?
count if (ELMAT945 == 2 | ELMAT945 == 3 | ELMAT945 == 4 | ELMAT945 == 5 | ELMAT945 == 6)

// How many more missing data do we have?
gen missingData = 0
foreach x of varlist currentGPA laggedGPA {
	replace missingData = 1 if `x' == .
}

tab missingData
drop missingData

// 
keep AID currentGPA laggedGPA

compress
cd $data_datasets_filepath
save AHAAgrades1.dta, replace
