// AUTHOR: Matthew A. Masten
//
// DATE CREATED: May 10, 2015
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies

/* Wave 1 in-home core */
cd ${ICPSR_root_filepath}ICPSR_27021/DS0001
describe using 27021-0001-Data-REST.dta, short
*Note that there are 2,820 variables. Too many for Stata/IC.
*So we have to specify what variables we want to import.

use /* 
*/ AID /* Identifier
*/ IMONTH IDAY IYEAR H1GI1M H1GI1Y /* Age variables
*/ H1GI4 H1GI6A-H1GI6E /* Race variables
*/ BIO_SEX /* Gender
*/ /* 
*/ H1GI14/* Were you born a U.S. citizen?
*/ /* 
*/ H1ED11 /* What was your most recent grade in English or language arts?
*/ H1ED12 /* in Math?
*/ H1ED13 /* in History or social studies?
*/ H1ED14 /* in Science?
*/ /*
*/ FR_FLAG /* Were they asked to nominate only 1, or up to 5 friends?
*/ H1MF6* H1FF6* /* "[Did you go] to his house in the last seven days"
*/ H1MF7* H1FF7* /* "[Did you meet] him after school to hang out or go somewhere in the last seven days"
*/ H1MF8* H1FF8* /* "[Did you spend] time with him last weekend"
*/ H1MF9* H1FF9* /* "[Did you talk]  with him about a problem in the last seven days"
*/ H1MF10* H1FF10* /* "[Did you talk] with him on the telephone in the last seven days"
*/ /* 
*/ H1RM1 H1RF1 /* Mother and father's education
*/ /*
*/ PA10 /* ``What is your current marital status?''
*/ PA12 /* ``How far did you go in school?''
*/ PB8 /* ``How far did your current (spouse/partner) go in school?''
*/ PA55 /* ``About how much total income, before taxes did your family receive in 1994?''
*/ /*
*/ using 27021-0001-Data-REST.dta, clear
compress

/* RECODE MISSING VALUES */
/* This code is taken from 27021-0001-Supplemental_synatx-REST.do, provided by Add Health */
replace H1GI1M = . if (H1GI1M == 96)
replace H1GI1Y = . if (H1GI1Y == 96)

/* Race variables */
replace H1GI4 = . if (H1GI4 == 6 | H1GI4 == 8)
replace H1GI6A = . if (H1GI6A >= 6 & H1GI6A <= 9)
replace H1GI6B = . if (H1GI6B >= 6 & H1GI6B <= 9)
replace H1GI6C = . if (H1GI6C >= 6 & H1GI6C <= 9)
replace H1GI6D = . if (H1GI6D >= 6 & H1GI6D <= 9)
replace H1GI6E = . if (H1GI6E >= 6 & H1GI6E <= 9)

replace BIO_SEX = . if (BIO_SEX == 6 | BIO_SEX == 8)


/* Were you born a U.S. citizen? */
replace H1GI14 = . if (H1GI14 == 6 | H1GI14 == 7 | H1GI14 == 8)

/* Subject grade variables */
replace H1ED11 = . if (H1ED11 >= 96 & H1ED11 <= 99)
replace H1ED12 = . if (H1ED12 >= 96 & H1ED12 <= 99)
replace H1ED13 = . if (H1ED13 >= 96 & H1ED13 <= 99)
replace H1ED14 = . if (H1ED14 >= 96 & H1ED14 <= 99)

/* Male friends related questions */
replace H1MF6A = . if (H1MF6A >= 6 & H1MF6A <= 9)
replace H1MF7A = . if (H1MF7A >= 6 & H1MF7A <= 9)
replace H1MF8A = . if (H1MF8A >= 6 & H1MF8A <= 9)
replace H1MF9A = . if (H1MF9A >= 6 & H1MF9A <= 9)
replace H1MF10A = . if (H1MF10A >= 6 & H1MF10A <= 9)

replace H1MF6B = . if (H1MF6B >= 6 & H1MF6B <= 9)
replace H1MF7B = . if (H1MF7B >= 6 & H1MF7B <= 9)
replace H1MF8B = . if (H1MF8B >= 6 & H1MF8B <= 9)
replace H1MF9B = . if (H1MF9B >= 6 & H1MF9B <= 9)
replace H1MF10B = . if (H1MF10B >= 6 & H1MF10B <= 9)

replace H1MF6C = . if (H1MF6C >= 6 & H1MF6C <= 9)
replace H1MF7C = . if (H1MF7C >= 6 & H1MF7C <= 9)
replace H1MF8C = . if (H1MF8C >= 6 & H1MF8C <= 9)
replace H1MF9C = . if (H1MF9C >= 6 & H1MF9C <= 9)
replace H1MF10C = . if (H1MF10C >= 6 & H1MF10C <= 9)

replace H1MF6D = . if (H1MF6D >= 6 & H1MF6D <= 9)
replace H1MF7D = . if (H1MF7D >= 6 & H1MF7D <= 9)
replace H1MF8D = . if (H1MF8D >= 6 & H1MF8D <= 9)
replace H1MF9D = . if (H1MF9D >= 6 & H1MF9D <= 9)
replace H1MF10D = . if (H1MF10D >= 6 & H1MF10D <= 9)

replace H1MF6E = . if (H1MF6E >= 6 & H1MF6E <= 9)
replace H1MF7E = . if (H1MF7E >= 6 & H1MF7E <= 9)
replace H1MF8E = . if (H1MF8E >= 6 & H1MF8E <= 9)
replace H1MF9E = . if (H1MF9E >= 6 & H1MF9E <= 9)
replace H1MF10E = . if (H1MF10E >= 6 & H1MF10E <= 9)

/* Female friends related questions */
replace H1FF6A = . if (H1FF6A >= 6 & H1FF6A <= 9)
replace H1FF7A = . if (H1FF7A >= 6 & H1FF7A <= 9)
replace H1FF8A = . if (H1FF8A >= 6 & H1FF8A <= 9)
replace H1FF9A = . if (H1FF9A >= 6 & H1FF9A <= 9)
replace H1FF10A = . if (H1FF10A >= 6 & H1FF10A <= 9)

replace H1FF6B = . if (H1FF6B >= 6 & H1FF6B <= 9)
replace H1FF7B = . if (H1FF7B >= 6 & H1FF7B <= 9)
replace H1FF8B = . if (H1FF8B >= 6 & H1FF8B <= 9)
replace H1FF9B = . if (H1FF9B >= 6 & H1FF9B <= 9)
replace H1FF10B = . if (H1FF10B >= 6 & H1FF10B <= 9)

replace H1FF6C = . if (H1FF6C == 7)
replace H1FF7C = . if (H1FF7C == 7)
replace H1FF8C = . if (H1FF8C == 7)
replace H1FF9C = . if (H1FF9C == 7)
replace H1FF10C = . if (H1FF10C == 7)

replace H1FF6D = . if (H1FF6D >= 6 & H1FF6D <= 9)
replace H1FF7D = . if (H1FF7D >= 6 & H1FF7D <= 9)
replace H1FF8D = . if (H1FF8D >= 6 & H1FF8D <= 9)
replace H1FF9D = . if (H1FF9D >= 6 & H1FF9D <= 9)
replace H1FF10D = . if (H1FF10D >= 6 & H1FF10D <= 9)

replace H1FF6E = . if (H1FF6E >= 6 & H1FF6E <= 9)
replace H1FF7E = . if (H1FF7E >= 6 & H1FF7E <= 9)
replace H1FF8E = . if (H1FF8E >= 6 & H1FF8E <= 9)
replace H1FF9E = . if (H1FF9E >= 6 & H1FF9E <= 9)
replace H1FF10E = . if (H1FF10E >= 6 & H1FF10E <= 9)

/* Mother and father's education */
replace H1RM1 = . if (H1RM1 >= 96 & H1RM1 <= 98)
replace H1RF1 = . if (H1RF1 >= 96 & H1RF1 <= 99)

/* Parent marital status */
replace PA10 = . if (PA10 == 6)

/* How far did parent go in schools */
replace PA12 = . if (PA12 == 96)

/* ``How far did your current (spouse/partner) go in school?'' */
replace PB8 = . if (PB8 == 96 | PB8 == 97)

/* ``About how much total income, before taxes did your family receive in 1994?'' */
replace PA55 = . if (PA55 == 9996)

/* CREATE RACE VARIABLE */
/* Code is based on http://www.cpc.unc.edu/projects/addhealth/data/code/race */

gen race=.
replace race=2 if H1GI6B==1 /* Black or African American, Non-Hispanic */
replace race=3 if H1GI6D==1 /* Asian, Non-Hispanic */
replace race=4 if H1GI6C==1 /* Native American, Non-Hispanic */
replace race=5 if H1GI6E==1 /* Other, Non-Hispanic */
replace race=6 if H1GI6A==1 /* White, Non-Hispanic */
replace race=1 if H1GI4==1  /* Hispanic, All Races */
*Note that the question H1GI4 over-rides any responses to the questions H1GI6A-E.

drop H1GI4 H1GI6A-H1GI6E
label define raceVals 1 "Hispanic, All Races" 2 "Black or African American, Non-Hispanic" /*
*/ 3 "Asian, Non-Hispanic" 4 "Native American, Non-Hispanic" 5 "Other, Non-Hispanic" /*
*/ 6 "White, Non-Hispanic"
label values race raceVals
label variable race "Race"

/* CREATE AGE (at wave 1) VARIABLE */
/* Code is based on http://www.cpc.unc.edu/projects/addhealth/data/code/bmi */

replace H1GI1M = . if H1GI1M == 96
replace H1GI1Y = . if H1GI1Y == 96

gen tempYear = IYEAR + 1900 /* IYEAR takes values 94 and 95 whereas mdy() requires full years as inputs */
gen intdt = mdy(IMONTH, IDAY, tempYear)
drop tempYear

gen tempYear = H1GI1Y + 1900
gen birthdt = mdy(H1GI1M, 15, tempYear)
drop tempYear

gen AGE = int((intdt-birthdt)/365.25)
label variable AGE "Age-W1"
drop intdt birthdt IMONTH IDAY IYEAR H1GI1M H1GI1Y

/* CREATE GPA (at wave 1) VARIABLE */

/* If they didn't take the subject (5) or it wasn't graded A-D (6) then just */ 
/* code it as missing */
replace H1ED11 = . if (H1ED11 == 5 | H1ED11 == 6)
replace H1ED12 = . if (H1ED12 == 5 | H1ED12 == 6)
replace H1ED13 = . if (H1ED13 == 5 | H1ED13 == 6)
replace H1ED14 = . if (H1ED14 == 5 | H1ED14 == 6)

/* A is coded as 1 and D(or lower) is coded as 4. Here I just flip that to */
/* make it more standard */
gen englishGrade = 5 - H1ED11
gen mathGrade = 5 - H1ED12
gen histSocSciGrade = 5 - H1ED13
gen scienceGrade = 5 - H1ED14
drop H1ED11 H1ED12 H1ED13 H1ED14

egen H1GPA = rmean(englishGrade mathGrade histSocSciGrade scienceGrade)
drop englishGrade mathGrade histSocSciGrade scienceGrade

/* MERGE WITH IN-HOME FRIEND NOMINATIONS DATA */
/* Both the master and using datasets have same number of obs, so the merge is straightforward */
cd ${ICPSR_root_filepath}ICPSR_27022/DS0001
merge AID using 27022-0001-Data-REST.dta, sort
drop _merge

compress
cd $data_datasets_filepath
save H1education1.dta, replace

