// AUTHOR: Matthew A. Masten
//
// DATE CREATED: August 20, 2012
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies

/* This code creates the main paired dataset.
It merges all of the individual level covariates into the pairs dataset
*/

// 1. Prepare the using datasets
cd $data_datasets_filepath
use H1education3.dta, clear

forvalues i = 1/2 {
	tempfile using`i'
	preserve
	foreach x of varlist _all {
		rename `x' `x'_`i'
	}
	save `using`i''
	restore
}

// 2. Prepare the master dataset
use pairsIH.dta, clear

forvalues i = 1/2 {
	rename AID`i' AID_`i'
	merge AID_`i' using `using`i'', sort
	drop if _merge != 3
	drop _merge
}

aorder // alphabetize the variable list

// 3. Pick out the relevant in-home interaction variables.
// Note: These variables are not used in the final analysis
forvalues person = 1/2 {
forvalues i = 6/10 {
gen H1F`i'_`person' = .
local j 1
foreach x in A B C D E {
	replace H1F`i'_`person' = H1MF`i'`x'_`person' if pairDef_`person' == "H`j'" & BIO_SEX_`person' == 1
	replace H1F`i'_`person' = H1FF`i'`x'_`person' if pairDef_`person' == "H`j'" & BIO_SEX_`person' == 2	
	
	local j = `j' + 1
	drop H1MF`i'`x'_`person' H1FF`i'`x'_`person'
}
}

label variable H1F6_`person' "Friends house"
label variable H1F7_`person' "Meet after school"
label variable H1F8_`person' "Time last weekend"
label variable H1F9_`person' "Talk about a prob"
label variable H1F10_`person' "Talk on phone"

}

// Drop the friend nomination related variables that are no longer needed
drop S34A_1-S43E_2
drop DAT_1 DAT_2
drop FR_FLAG_1 FR_FLAG_2
drop FF1AID_1-FF_AID5_2
drop MF1AID_1-MF_AID5_2

// 4. Save the dataset
compress
save H1education4.dta, replace

