// AUTHOR: Matthew A. Masten
//
// DATE CREATED: Sept 25, 2012
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies

// This code selects out the variables we want for the final estimation sample

cd $data_datasets_filepath
use H1education4.dta, clear

// If the AHAA current GPA data is missing, fill it in from the in-home survey
forvalues i = 1/2 {
	replace currentGPA_`i' = H1GPA_`i' if currentGPA_`i' == .
} 

// Select variables we want to keep
forvalues i = 1/2 {

local listofvarstokeep_`i' /*
*/ AGE_`i' /*
*/ AID_`i' /*
*/ BIO_SEX_`i' /* Gender
*/ currentGPA_`i' /*
*/ laggedGPA_`i' /*
*/ race_`i'

}

keep pairID `listofvarstokeep_1' `listofvarstokeep_2'

//  Create a missing data indicator variable

gen missingData = 0
gen nVarsWmissData = 0
foreach x of varlist _all {
	capture confirm string variable `x' 
	// Check whether `x' is a string variable. _rc is true if `x' is NOT a string.
	if _rc {
		replace missingData = 1 if `x' == .
		replace nVarsWmissData = nVarsWmissData + 1 if `x' == .
	}
}

save H1education5.dta, replace
