// AUTHOR: Matthew A. Masten
//
// DATE CREATED: August 12, 2012
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies
//
// DESCRIPTION:
// This code creates the dataset friendNominations_M and friendNominations_F
// 1. It drops all variables except for AID and the friend nomination variables.
//
// 2. It ensures that, for each observation, all friend nominations within the in-home survey are unique; 
// likewise for the in school survey. For example, suppose one person nominated another person as both 
// their best and their second best friend. I erase the lowest ranked entry, so that their second best 
// friend is now recorded as missing.

local genderIndex 1
foreach gender in M F {

cd $data_datasets_filepath
use H1education3.dta, clear

if `genderIndex' == 1 {
	keep if BIO_SEX == 1 // Recall that male=1, female=2
}
else {
	keep if BIO_SEX == 2
}

keep AID `gender'F1AID-`gender'F5AID `gender'F_AID1-`gender'F_AID5

// Several people picked the same friend as their 1st and 2nd best friend!
// The following code deletes these multiple nominations
forvalues i = 1/5 {
forvalues j = 1/5 {
if `i' < `j' {

replace `gender'F_AID`j' = "" if `gender'F_AID`i' == `gender'F_AID`j' & `gender'F_AID`j' != ""
replace `gender'F`j'AID = "" if `gender'F`i'AID == `gender'F`j'AID & `gender'F`j'AID != ""

}
}
}

cd $data_cr_data_datasets_filepath
save friendNominations_`gender'.dta, replace

local genderIndex = `genderIndex' + 1
}
