// AUTHOR: Matthew A. Masten
//
// DATE CREATED: August 12, 2012
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies
//
// DESCRIPTION: Converts nomination variables into unique friend pair variables. 
// Subsequent code will pick out just one of these pairID variables as the 
// relevant match.

foreach gender in M F {

cd $data_cr_data_datasets_filepath
use friendNominations_`gender'.dta, replace

forvalues i = 1/5 {

gen pairID_IH`gender'F`i' = ""
gen pairID_IS`gender'F`i' = ""

gen firstIH`i' = "" // Temporary variables
gen secondIH`i' = ""
gen firstIS`i' = ""
gen secondIS`i' = ""

gen condIH`i' = `gender'F_AID`i' != ""
replace firstIH`i' = cond(AID < `gender'F_AID`i', AID, `gender'F_AID`i') if condIH`i'
replace secondIH`i' = cond(AID < `gender'F_AID`i', `gender'F_AID`i',AID)  if condIH`i'

gen condIS`i' = `gender'F`i'AID != ""
replace firstIS`i' = cond(AID < `gender'F`i'AID, AID, `gender'F`i'AID) if condIS`i'
replace secondIS`i' = cond(AID < `gender'F`i'AID, `gender'F`i'AID,AID) if condIS`i'

replace pairID_IH`gender'F`i' = firstIH`i' + secondIH`i' if condIH`i'
replace pairID_IS`gender'F`i' = firstIS`i' + secondIS`i' if condIS`i'
drop firstIH`i' secondIH`i' condIH`i' firstIS`i' secondIS`i' condIS`i'

}

drop `gender'F1AID-`gender'F5AID `gender'F_AID1-`gender'F_AID5
save friendNominations_`gender'_withIDs.dta, replace
// This dataset has 10 different pairID variables for each person, depending on whether we pair that person 
// with each of the 10 (possibly different) people they nominated: in-home 1-5 and in-school 1-5

}
