// AUTHOR: Matthew A. Masten
//
// DATE CREATED: August 21, 2012
// DATE LAST UPDATED: July 14, 2017
//
// REFERENCE: Masten (2017) "Random Coefficients on Endogenous Variables in
// Simultaneous Equations Models", Review of Economic Studies
//
// DESCRIPTION:
//
// This program creates all required datasets from the provided ICPSR data
// Note on variable names: H1=in-home wave 1 survey. GI=general introduction.
//

version 10
clear all
set mem 500m
set more off

// Directory containing the ICPSR folders
global ICPSR_root_filepath /Volumes/untitled/

// Directory containing create data program code
local cr_data_program_filepath /Users/Matt/Dropbox/Research/AHD_analysis_JMP_Education/stata/cr_data/programs

// Directories containing datasets, main and temporary
global data_datasets_filepath /Volumes/untitled/data/datasets
global data_cr_data_datasets_filepath /Volumes/untitled/data/cr_data_datatemp

///////////////////////////////////////////////////////////////////////////
cd `cr_data_program_filepath'
do cr_AHAAgrades1.do 
// Gets overall HS GPA for each HS year, and their grade level during 1994-1995

cd `cr_data_program_filepath'
do cr_H1education1.do 
// 1. Selects variables from in-home wave 1 survey
// 2. Recodes missing values
// 3. Generates desired new variables
// 4. Merges in-home wave 1 friend nominations data (Note that MF_AID is the in-home variable; MFAID is the in-school variable)

cd `cr_data_program_filepath'
do cr_H1education2.do 
// Merge the AHAA grade data with the in-home wave 1 data

cd `cr_data_program_filepath'
do cr_H1education3.do
// Merges in-school wave 1 friend nominations data, plus the interaction variables
// Why use the in-school nominations too? Because they are much richer than the 
// in home nominations data, and so  will lead to more pairs of friends actually
// matching in the data
//
// Note: Although I merge this data in here, I do not actually use it in the final analysis

cd `cr_data_program_filepath'
do recodeFriendData.do
// Recodes the friend nomination variables, so that nominated friends who do not appear in 
// the dataset are counted as missing data. Also convertes in-school wave 1 friend nominations to strings.

cd `cr_data_program_filepath'
do cr_friendNominations.do
// 1. Drops all but friend nomination variables
// 2. Cleans the nomination variables a bit (eliminates double-nominations)

cd `cr_data_program_filepath'
do cr_friendNominations_withIDs.do
// Creates a dataset with the variable AID and 10 different pairID variables for each male student, depending on 
// whether we pair that person with each of the 10 (possibly different) people they nominated: in-home 1-5 and in-school 1-5

cd `cr_data_program_filepath'
do cr_pairsIH.do
// Creates a dataset of (AID1,AID2) pairs based on the friend nomination questions from the in-home survey.

cd `cr_data_program_filepath'
do cr_H1education4.do
// Merges the individual level data into the ID pairs
// Also picks out the correct interaction variables
// This code creates the semi-final dataset. All that remains below is to pick out the precise variables desired,
// and to deal with missing data, before exporting to MATLAB

cd `cr_data_program_filepath'
do cr_H1education5.do
// Select the covariates we want for the final estimation sample

cd `cr_data_program_filepath'
do exportDataToMatlab.do
